#' @title macroKZ dataset
#' @format A time series data frame of 57 quarterly observations of 50 macroeconomic and 10 financial parameters for 2010-2024 period.
#' \describe{
#'  \item{real_gdp}{Real GDP}
#'  \item{GDD_Agr_R}{Real gross value added Agriculture}
#'  \item{GDD_Min_R}{Real gross value added Mining}
#'  \item{GDD_Min_R}{Real gross value added Mining}
#'  \item{GDD_Man_R}{Real gross value added Manufacture}
#'  \item{GDD_Elc_R}{Real gross value added Electricity}
#'  \item{GDD_Con_R}{Real gross value added Construction}
#'  \item{GDD_Trd_R}{Real gross value added Trade}
#'  \item{GDD_Trn_R}{Real gross value added Transportation}
#'  \item{GDD_Inf_R}{Real gross value added Information}
#'  \item{GDD_R}{Real gross value added}
#'  \item{GDP_DEF}{GDP deflator}
#'  \item{Rincpop_q}{Real population average monthly income}
#'  \item{Rexppop_q}{Real population average monthly expenses}
#'  \item{Rwage_q}{Real population average monthly wage}
#'  \item{imp}{Import}
#'  \item{exp}{Export}
#'  \item{cpi}{Inflation}
#'  \item{realest_resed_prim}{Real price for estate in primary market}
#'  \item{realest_resed_sec}{Real price for estate in secondary market}
#'  \item{realest_comm}{Real price for commercial estate}
#'  \item{index_stock_weighted}{Change in stock value for traded companies}
#'  \item{ntrade_Agr}{Change in stock value for non-traded companies Agriculture}
#'  \item{ntrade_Min}{Change in stock value for non-traded companies Mining}
#'  \item{ntrade_Man}{Change in stock value for non-traded companies Manufacture}
#'  \item{ntrade_Elc}{Change in stock value for non-traded companies Electricity}
#'  \item{ntrade_Con}{Change in stock value for non-traded companies Construction}
#'  \item{ntrade_Trd}{Change in stock value for non-traded companies Trade}
#'  \item{ntrade_Trn}{Change in stock value for non-traded companies Transportation}
#'  \item{ntrade_Inf}{Change in stock value for non-traded companies Information}
#'  \item{fed_fund_rate}{Federal Funds Rate}
#'  \item{govsec_rate_kzt_3m}{Return on government securities in KZT, 3 m}
#'  \item{govsec_rate_kzt_1y}{Return on government securities in KZT, 1 year}
#'  \item{govsec_rate_kzt_7y}{Return on government securities in KZT, 7 years}
#'  \item{govsec_rate_kzt_10y}{Return on government securities in KZT, 10 years}
#'  \item{tonia_rate}{TONIA}
#'  \item{rate_kzt_mort_0y_1y}{Weighted average mortgage lending rate for new loans, less than a year}
#'  \item{rate_kzt_mort_1y_iy}{Weighted average mortgage lending rate for new loans, more than a year}
#'  \item{rate_kzt_corp_0y_1y}{Weighted average mortgage lending rate for new loans to non-financial organizations in KZT, less than a year}
#'  \item{rate_usd_corp_0y_1y}{Weighted average mortgage lending rate for new loans to non-financial organizations in CKB, less than a year}
#'  \item{rate_kzt_corp_1y_iy}{Weighted average mortgage lending rate for new loans to non-financial organizations in KZT, more than a year}
#'  \item{rate_usd_corp_1y_iy}{Weighted average mortgage lending rate for new loans to non-financial organizations in CKB, more than a year}
#'  \item{rate_kzt_indv_0y_1y}{Weighted average mortgage lending rate for consumer loans in KZT, less than a year}
#'  \item{rate_kzt_indv_1y_iy}{Weighted average mortgage lending rate for consumer loans in KZT, less than a year}
#'  \item{usdkzt}{USD KZT exchange rate}
#'  \item{eurkzt}{EUR KZT exchange rate}
#'  \item{rurkzt}{RUB KZT exchange rate}
#'  \item{poil}{Price for Brent}
#'  \item{realest_resed_prim_rus}{Real price for estate in primary market in Russia}
#'  \item{realest_resed_sec_rus}{Real price for estate in secondary market in Russia}
#'  \item{cred_portfolio}{credit portfolio}
#'  \item{coef_liq_k4}{k4 prudential coefficient}
#'  \item{coef_k1}{k1 prudential coefficient}
#'  \item{coef_k3}{k3 prudential coefficient}
#'  \item{provisions}{provisions}
#'  \item{percent_margin}{percent margin}
#'  \item{com_inc}{commissionary income}
#'  \item{com_exp}{commissionary expenses}
#'  \item{oper_inc}{operational income}
#'  \item{oth_inc}{other income}
#'  \item{DR}{default rate}
#'}
#' @source Bureau of National statistics, Agency for Strategic planning and reforms of the Republic of Kazakhstan
#' @references The Agency of the Republic of Kazakhstan for Regulation and Development of Financial Market
'macroKZ'
